@@ -189,3 +189,43 @@ class BuildbotSlave(Buildbot):
     def update(self):
         pass
 
+def uninstall_buildbotslave(name, options):
+    """ called before auto uninstallation of the slave """
+    _check_running_buildbot(name, options)
+
+    process = subprocess.Popen(['ps', 'aux'], shell=False, stdout=subprocess.PIPE)
+    result = process.communicate()[0].split('\n')
+    if len([r for r in result if r.find(name)]):
+        print """**** warning: found a buildbot master but there was no twistd.pid file
+        If there are no other expected buildbot instances expected, please stop buildbot, find and stop (kill) any rogue buildbots and start buildbot again ****"""
+
+def uninstall_buildbotmaster(name, options):
+    """ called before auto uninstallation of the master """
+    _check_running_buildbot(name, options)
+
+    process = subprocess.Popen(['ps', 'aux'], shell=False, stdout=subprocess.PIPE)
+    result = process.communicate()[0].split('\n')
+    if len([r for r in result if r.find(name)]):
+        print """**** warning: found a buildbot master but there was no twistd.pid file
+        If there are no other expected buildbot instances expected, please stop buildbot, find and stop (kill) any rogue buildbots and start buildbot again ****"""
+
+def _check_running_buildbot(name, options):
+    basedir = options["basedir"]
+
+    pid_file_path = os.path.join(basedir,'twistd.pid')
+    if not os.path.isfile(pid_file_path):
+        return
+
+    pid = open(pid_file_path,'r').read()
+    try:
+        pid = int(pid)
+    except:
+        raise UserError("The pid file for '%s' is corrupted. Cannot continue." % name)
+
+    try:
+        os.kill(pid, 0)
+        raise UserError("Buildbot still appears to be running. Please stop it, re-run buildout and then re-start buildbot if required. If this error still results, check for buildbot processes manually and delete %s" % pid_file_path)
+    except OSError, e:
+        if e.errno == 3:
+            raise UserError("We don't have permission to check the status of the buildbot")
+
